Search.setIndex({envversion:42,terms:{content:0,index:0,modul:0,search:0,page:0},objtypes:{},objnames:{},filenames:["index"],titles:["Welcome to Stormtracks&#8217;s documentation!"],objects:{},titleterms:{stormtrack:0,document:0,welcom:0,indic:0,tabl:0}})